// java wrapper for vtkPassThrough object
//

package vtk;
import vtk.*;

public class vtkPassThrough extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int FillInputPortInformation_2(int id0,vtkInformation id1);
  public int FillInputPortInformation(int id0,vtkInformation id1)
    { return FillInputPortInformation_2(id0,id1); }

  private native void SetDeepCopyInput_3(int id0);
  public void SetDeepCopyInput(int id0)
    { SetDeepCopyInput_3(id0); }

  private native int GetDeepCopyInput_4();
  public int GetDeepCopyInput()
    { return GetDeepCopyInput_4(); }

  private native void DeepCopyInputOn_5();
  public void DeepCopyInputOn()
    { DeepCopyInputOn_5(); }

  private native void DeepCopyInputOff_6();
  public void DeepCopyInputOff()
    { DeepCopyInputOff_6(); }

  private native void SetAllowNullInput_7(boolean id0);
  public void SetAllowNullInput(boolean id0)
    { SetAllowNullInput_7(id0); }

  private native boolean GetAllowNullInput_8();
  public boolean GetAllowNullInput()
    { return GetAllowNullInput_8(); }

  private native void AllowNullInputOn_9();
  public void AllowNullInputOn()
    { AllowNullInputOn_9(); }

  private native void AllowNullInputOff_10();
  public void AllowNullInputOff()
    { AllowNullInputOff_10(); }

  public vtkPassThrough() { super(); }

  public vtkPassThrough(long id) { super(id); }
  public native long   VTKInit();

}
